@@ -1,12 +1,6 @@
 ################################################################################
 ## plumber utility endpoint
 ################################################################################
-# Global code; gets executed at plumb() time.
-pkgload::load_all()
-plan <- purrr::partial(future::plan, workers = future::availableCores())
-if (future::supportsMulticore()) plan(future::multicore) else plan(future::multisession)
-
-
 # Utilities ---------------------------------------------------------------
 #* Health check
 #* Respond when you ask it if a service is available.
@@ -24,6 +18,6 @@ function(){
 function(req){
     message("--> class: Request Received")
     json <- req$postBody
-    x <- json %>% jsonlite::fromJSON(flatten = TRUE)
+    x <- json |> jsonlite::fromJSON(flatten = TRUE)
     return(class(x))
 }
